==> haskell-http-download-0.2.1.0-279-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-DZQcz3ccQEnAIIrpAZ42wd
key:                  http-download-0.2.1.0-DZQcz3ccQEnAIIrpAZ42wd
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  4de39c6096920e2a2a310b6fcc4d69e0
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-DZQcz3ccQEnAIIrpAZ42wd
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-BuaE7coGml7AORbY2RxXh2
    bytestring-0.11.5.3 conduit-1.3.6.1-Iv674JaqEE17PR7slCoUfp
    conduit-extra-1.3.8-9BT5gTgmegiEww1RLwnr5K
    crypton-1.0.3-4UnAyWN8beXD5nwa7txFxR
    crypton-conduit-0.2.3-8zxOHqFxP57EsTZ2UA5YLZ directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.19-LRfftiQ6YWX88xW4fFXEK8
    http-conduit-2.3.9.1-CPmopMKYDZmGtVTs3jcq5H
    http-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    path-0.9.5-1jZpzQ0vjAO5iVFuHisUvB
    path-io-1.8.2-97mx8StNnup5YVGZ4eESpD
    retry-0.9.3.1-EAfvvx73dx91MIUnhmmiuB
    rio-0.1.22.0-FRVl3z1YqEoDlmYLA6axyl
    rio-prettyprint-0.1.8.0-GoOumGC1b2A7GQKpL80g5T

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.2.1.0-280-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-6n27Nh5mRvd94q3GDdWsL9
key:                  http-download-0.2.1.0-6n27Nh5mRvd94q3GDdWsL9
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  46b3d706eff480d8cbfdd4090aafec3f
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-6n27Nh5mRvd94q3GDdWsL9
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-7CU13IWnWdcDMU9nDc25iT
    bytestring-0.11.5.3 conduit-1.3.6.1-6EN3TiAZvJYIfvMY9NMvKR
    conduit-extra-1.3.8-ocqV3ZQIM7JZjciPRh2Zy
    crypton-1.0.3-4fmgkM3o5KLw34vBuyh6F
    crypton-conduit-0.2.3-9anMgTp0XKVC3sSRq9RUZQ directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.19-B8l1xqF9CzrAQJibWsxIAb
    http-conduit-2.3.9.1-3unIqyPQbILE7LHBwWMmkF
    http-types-0.12.4-9GhteoJuOlZ3ATAYoIbhkU
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    path-0.9.5-16Np9pWWm6C6X6VRNGon34
    path-io-1.8.2-HZGLQKtNn0VHYHvfCLNrlF
    retry-0.9.3.1-mWs1rYY0do5eaKecxaidi
    rio-0.1.22.0-Cb33pQgILlS4LucL3Ov2a2
    rio-prettyprint-0.1.8.0-IgX1rTnQ2VFCdc2KT4dtmd

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
